.. _users-guide-index:

============
 User Guide
============
	
:Release: |version|
:Date: |today|

.. toctree::
   :maxdepth: 2

   overview
   install
   tutorial

.. todo::

    Add brief overview of the timeseries code.

